.. _github-stats_3-10-8:

GitHub statistics for 3.10.8 (Nov 12, 2025)
===========================================

GitHub statistics for 2024/12/14 (tag: v3.10.0) - 2025/11/12

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 4 issues and merged 16 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/106?closed=1>`__

The following 35 authors contributed 445 commits.

* Aasma Gupta
* Antony Lee
* Christine P. Chai
* David Stansby
* dependabot[bot]
* Elliott Sales de Andrade
* G.D. McBain
* Greg Lucas
* hannah
* heinrich5991
* hu-xiaonan
* Ian Thomas
* Inês Cachola
* Jody Klymak
* Jouni K. Seppänen
* Khushi_29
* Kyle Sunden
* Lucas Gruwez
* Lumberbot (aka Jack)
* N R Navaneet
* Nathan G. Wiseman
* Nathan Goldbaum
* Nick Coish
* Oscar Gustafsson
* Praful Gulani
* Qian Zhang
* Rafael Katri
* Raphael Erik Hviding
* Roman
* Ruth Comer
* saikarna913
* Scott Shambaugh
* Thomas A Caswell
* Tim Hoffmann
* Trygve Magnus Ræder

GitHub issues and pull requests:

Pull Requests (16):

* :ghpull:`30717`: Backport PR #30714 on branch v3.10.x (FIX: Gracefully handle numpy arrays as input to check_in_list())
* :ghpull:`30714`: FIX: Gracefully handle numpy arrays as input to check_in_list()
* :ghpull:`30560`: Consistent zoom boxes
* :ghpull:`30711`: Backport PR #30697 on branch v3.10.x (BUG: raise when creating a MacOS FigureManager outside the main thread)
* :ghpull:`30697`: BUG: raise when creating a MacOS FigureManager outside the main thread
* :ghpull:`30656`: Backport PR #29810 on branch v3.10.x (Declare free-threaded support in MacOS backend extension)
* :ghpull:`30702`: Backport PR #30624 on branch v3.10.x (TST: Increase tolerances for Ghostscript 10.06)
* :ghpull:`30700`: Backport PR #30698 on branch v3.10.x (BLD: update trove metadata to support py3.14)
* :ghpull:`30624`: TST: Increase tolerances for Ghostscript 10.06
* :ghpull:`30698`: BLD: update trove metadata to support py3.14
* :ghpull:`30688`: Backport PR #30687 on branch v3.10.x (DOC: Fix pip link)
* :ghpull:`30675`: Backport PR #30657 on branch v3.10.x (Fix AttributeError: module 'gi' has no attribute 'require_version')
* :ghpull:`30674`: Backport PR #30672 on branch v3.10.x (Use pathlib.Path instead of matplotlib.path.Path in text.pyi)
* :ghpull:`30672`: Use pathlib.Path instead of matplotlib.path.Path in text.pyi
* :ghpull:`30657`: Fix ``AttributeError: module 'gi' has no attribute 'require_version'``
* :ghpull:`29810`: Declare free-threaded support in MacOS backend extension

Issues (4):

* :ghissue:`30706`: [Bug]: Axes.grouped_bar() with non-string orientation (e.g., NumPy array) raises ambiguous truth-value error instead of clean ValueError
* :ghissue:`30666`: [Bug]: calling pyplot.gca() outside the main thread crashes the interpreter with the MacOS backend
* :ghissue:`30669`: [Bug]: Type hint for fontproperties keyword in text.pyi is wrong
* :ghissue:`30654`: [Bug]: error plotting: AttributeError: module 'gi' has no attribute 'require_version'
